GWCS
====

Generalized World Coordinate System (GWCS) is an `Astropy`_ affiliated package providing tools for managing the World Coordinate System of astromnomical data.


Note
----
Beginning with the next version (0.9), GWCS requires Python 3.5 and above.


Installation
------------

To install::

    pip install gwcs  # Make sure pip >= 9.0.1 is used.

To clone from github and install the master branch::

    git clone https://github.com/spacetelescope/gwcs.git
    cd gwcs
    python setup.py install

Status
------

.. image:: https://travis-ci.org/spacetelescope/gwcs.svg
    :target: https://travis-ci.org/spacetelescope/gwcs
    :alt: GWCS's Travis CI Status
.. image:: https://coveralls.io/repos/github/spacetelescope/gwcs/badge.svg?branch=master
    :target: https://coveralls.io/github/spacetelescope/gwcs?branch=master
    :alt: Test Coverage Status


Citing GWCS
-----------

.. image:: https://zenodo.org/badge/29208937.svg
   :target: https://zenodo.org/badge/latestdoi/29208937

If you use GWCS, please cite the package via its Zenodo record.

License
-------

GWCS is licensed under a 3-clause BSD style license.

.. _Astropy: http://www.astropy.org/
